@@ -1,4 +1,8 @@
-get_oc_gBOIN_Continuous <-function(target,c_true,ncohort,cohortsize,ntrial,mu_1=0.6*target,mu_2=1.4*target,startdose = 1, seed = 100){
+get_oc_gBOIN_Continuous <-function(target,c_true,ncohort,cohortsize, n.earlystop = 100, ntrial,mu_1=0.6*target,mu_2=1.4*target,startdose = 1, seed = 100){
+  if (n.earlystop <= 6) {
+    cat("Warning: the value of n.earlystop is too low to ensure good operating characteristics. Recommend n.earlystop = 9 to 18 \n")
+    return()
+  }
   set.seed(seed)
   ndose = length(c_true)
   npts = ncohort * cohortsize
@@ -10,8 +14,10 @@ get_oc_gBOIN_Continuous <-function(target,c_true,ncohort,cohortsize,ntrial,mu_1=
     n <- rep(0, ndose)
     d = startdose
     for (i in 1:ncohort) {
-      y[d] = y[d] + sum(rnorm(cohortsize,c_true[d],0.05*d))#0.2*d))
+      y[d] = y[d] + sum(rnorm(cohortsize,c_true[d],0.3*d))#0.2*d))
       n[d] = n[d] + cohortsize
+      if (n[d] >= n.earlystop)
+        break
       if (y[d]/n[d] <=(target+mu_1)/2&& d != ndose) {
           d = d + 1
       }
